==> cscec5b-rmat-api-3.0.1-20221021.093018-17-sources.jar: com/ejianc/business/rmat/vo/TransferFlowVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 内部调拨流水表
 * 
 * @author generator
 * 
 */
public class TransferFlowVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billTypeCode; // 来源单据类型编码
    private Long sourceId; // 来源单据id
    private Long sourceDetailId; // 来源单据明细id
    private String billCode; // 来源单据编码
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Long orgId; // 所属组织
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private Long contractId; // 合同id
    private String contractCode; // 合同编号
    private String contractName; // 合同名称
    private Long supplierId; // 供应商id
    private String supplierName; // 供应商名称
    private Long employeeId; // 业务经办人ID
    private String employeeName; // 业务经办人名称
    private Date billDate; // 来源单据日期
    private Date effectiveDate; // 生效时间
    private Integer effectiveState; // 生效状态0自由1已生效
    private String flowType; // 流水类型: 1-验收，2-退场，3-调入，4-调出
    private Integer inOutFlag; // 进退场属性1进场2退场
    private Long materialTypeId; // 物资分类id
    private String materialTypeName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String rentCalculationType; // 计租方式：0-普通计租 / 1-延长米计租
    private Integer sourceType; // 材料来源,0-在场材料,1-周转材档案
    private Date detailDate; // 来源单据明细日期
    private String materialSourceId; // 物资来源主键
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal amount; // 数量
    private BigDecimal realOnHandNums; // 实物在场数量
    private BigDecimal sumNums; // 累计实物数量
    private BigDecimal sumOnHandNums;//累计实物进场数量
    private BigDecimal sumExitNums;//累计实物退场数量
    private String queryId; // 查询id projectId + supplierId
    private String useStatus;//占用状态 0-未占用 1-全部占用 2-部分占用
    private BigDecimal occupNum;//占用数量
    private String occupId;//占用单据id

    private List<TransferFlowVO> detailList = new ArrayList<>(); // 物资在场材料
    private List<TransferFlowVO> rmatDetailList = new ArrayList<>(); //物资周转明细

    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public Integer getEffectiveState() {
        return effectiveState;
    }

    public void setEffectiveState(Integer effectiveState) {
        this.effectiveState = effectiveState;
    }
    public String getFlowType() {
        return flowType;
    }

    public void setFlowType(String flowType) {
        this.flowType = flowType;
    }
    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Date getDetailDate() {
        return detailDate;
    }

    public void setDetailDate(Date detailDate) {
        this.detailDate = detailDate;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public BigDecimal getSumOnHandNums() {
        return sumOnHandNums;
    }

    public void setSumOnHandNums(BigDecimal sumOnHandNums) {
        this.sumOnHandNums = sumOnHandNums;
    }

    public BigDecimal getSumExitNums() {
        return sumExitNums;
    }

    public void setSumExitNums(BigDecimal sumExitNums) {
        this.sumExitNums = sumExitNums;
    }

    public String getQueryId() {
        return queryId;
    }

    public void setQueryId(String queryId) {
        this.queryId = queryId;
    }

    public BigDecimal getRealOnHandNums() {
        return realOnHandNums;
    }

    public void setRealOnHandNums(BigDecimal realOnHandNums) {
        this.realOnHandNums = realOnHandNums;
    }

    public List<TransferFlowVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<TransferFlowVO> detailList) {
        this.detailList = detailList;
    }

    public List<TransferFlowVO> getRmatDetailList() {
        return rmatDetailList;
    }

    public void setRmatDetailList(List<TransferFlowVO> rmatDetailList) {
        this.rmatDetailList = rmatDetailList;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public BigDecimal getOccupNum() {
        return occupNum;
    }

    public void setOccupNum(BigDecimal occupNum) {
        this.occupNum = occupNum;
    }

    public String getOccupId() {
        return occupId;
    }

    public void setOccupId(String occupId) {
        this.occupId = occupId;
    }

    public BigDecimal getSumNums() {
        return sumNums;
    }

    public void setSumNums(BigDecimal sumNums) {
        this.sumNums = sumNums;
    }
}

==> cscec5b-rmat-api-3.0.1-20221027.035229-31-sources.jar: com/ejianc/business/rmat/vo/TransferFlowVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 内部调拨流水表
 * 
 * @author generator
 * 
 */
public class TransferFlowVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billTypeCode; // 来源单据类型编码
    private Long sourceId; // 来源单据id
    private Long sourceDetailId; // 来源单据明细id
    private String billCode; // 来源单据编码
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Long orgId; // 所属组织
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private String contractId; // 合同id
    private String contractCode; // 合同编号
    private String contractName; // 合同名称
    private Long supplierId; // 供应商id
    private String supplierName; // 供应商名称
    private Long employeeId; // 业务经办人ID
    private String employeeName; // 业务经办人名称
    private Date billDate; // 来源单据日期
    private Date effectiveDate; // 生效时间
    private Integer effectiveState; // 生效状态0自由1已生效
    private String flowType; // 流水类型: 1-验收，2-退场，3-调入，4-调出
    private Integer inOutFlag; // 进退场属性1进场2退场
    private Long materialTypeId; // 物资分类id
    private String materialTypeName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String rentCalculationType; // 计租方式：0-普通计租 / 1-延长米计租
    private Integer sourceType; // 材料来源,0-在场材料,1-周转材档案
    private Date detailDate; // 来源单据明细日期
    private String materialSourceId; // 物资来源主键
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal amount; // 数量
    private BigDecimal realOnHandNums; // 实物在场数量
    private BigDecimal sumNums; // 累计实物数量
    private BigDecimal sumOnHandNums;//累计实物进场数量
    private BigDecimal sumExitNums;//累计实物退场数量
    private String queryId; // 查询id projectId + supplierId
    private String useStatus;//占用状态 0-未占用 1-全部占用 2-部分占用
    private String occupNum;//占用数量
    private String occupId;//占用单据id

    private List<TransferFlowVO> detailList = new ArrayList<>(); // 物资在场材料
    private List<TransferFlowVO> rmatDetailList = new ArrayList<>(); //物资周转明细

    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public Integer getEffectiveState() {
        return effectiveState;
    }

    public void setEffectiveState(Integer effectiveState) {
        this.effectiveState = effectiveState;
    }
    public String getFlowType() {
        return flowType;
    }

    public void setFlowType(String flowType) {
        this.flowType = flowType;
    }
    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Date getDetailDate() {
        return detailDate;
    }

    public void setDetailDate(Date detailDate) {
        this.detailDate = detailDate;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public BigDecimal getSumOnHandNums() {
        return sumOnHandNums;
    }

    public void setSumOnHandNums(BigDecimal sumOnHandNums) {
        this.sumOnHandNums = sumOnHandNums;
    }

    public BigDecimal getSumExitNums() {
        return sumExitNums;
    }

    public void setSumExitNums(BigDecimal sumExitNums) {
        this.sumExitNums = sumExitNums;
    }

    public String getQueryId() {
        return queryId;
    }

    public void setQueryId(String queryId) {
        this.queryId = queryId;
    }

    public BigDecimal getRealOnHandNums() {
        return realOnHandNums;
    }

    public void setRealOnHandNums(BigDecimal realOnHandNums) {
        this.realOnHandNums = realOnHandNums;
    }

    public List<TransferFlowVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<TransferFlowVO> detailList) {
        this.detailList = detailList;
    }

    public List<TransferFlowVO> getRmatDetailList() {
        return rmatDetailList;
    }

    public void setRmatDetailList(List<TransferFlowVO> rmatDetailList) {
        this.rmatDetailList = rmatDetailList;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public String getOccupNum() {
        return occupNum;
    }

    public void setOccupNum(String occupNum) {
        this.occupNum = occupNum;
    }

    public String getOccupId() {
        return occupId;
    }

    public void setOccupId(String occupId) {
        this.occupId = occupId;
    }

    public BigDecimal getSumNums() {
        return sumNums;
    }

    public void setSumNums(BigDecimal sumNums) {
        this.sumNums = sumNums;
    }
}
